"""reface URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.1/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
import json
import os

from django.urls import re_path
from django.views.i18n import JavaScriptCatalog

import reface.dashboard.views

try:
    with open(os.environ.get('REFACE_CONFIG'), 'r') as fs:
        HTTP_ROOT = json.load(fs)['http_root']
except:
    HTTP_ROOT = 'rapida'


urlpatterns = [
    re_path(f'{HTTP_ROOT}' + r'/box/(?P<box_id>\d+)/', reface.dashboard.views.box),
    re_path(f'{HTTP_ROOT}' + r'/(?P<box_id>\d+)/(?P<module_id>\d+)/(?P<channel_id>\d+)/builder/$', reface.dashboard.views.line_builder),
    re_path(f'{HTTP_ROOT}' + r'/(?P<box_id>\d+)/(?P<module_id>\d+)/(?P<channel_id>\d+)/addressing/$', reface.dashboard.views.address_editor),
    re_path(f'{HTTP_ROOT}' + r'/(?P<box_id>\d+)/(?P<module_id>\d+)/(?P<channel_id>\d+)/probation/$', reface.dashboard.views.probation),
    re_path(f'{HTTP_ROOT}' + r'/(?P<box_id>\d+)/(?P<module_id>\d+)/(?P<channel_id>\d+)/builder/process/$', reface.dashboard.views.line_builder_process),
    re_path(f'{HTTP_ROOT}' + r'/(?P<box_id>\d+)/(?P<module_id>\d+)/(?P<channel_id>\d+)/devices/$', reface.dashboard.views.devices),
    re_path(f'{HTTP_ROOT}' + r'/(?P<box_id>\d+)/(?P<module_id>\d+)/(?P<channel_id>\d+)/monitor/$', reface.dashboard.monitor.Dali.as_view()),
    re_path(f'{HTTP_ROOT}' + r'/(?P<box_id>\d+)/(?P<module_id>\d+)/(?P<channel_id>\d+)/$', reface.dashboard.views.channel),
    re_path(f'{HTTP_ROOT}' + r'/(?P<box_id>\d+)/(?P<module_id>\d+)/$', reface.dashboard.views.module),
    re_path(f'{HTTP_ROOT}' + r'/(?P<box_id>\d+)/set_name', reface.dashboard.views.set_box_name),
    re_path(f'{HTTP_ROOT}' + r'/configure/$', reface.dashboard.views.configure),
    re_path(f'{HTTP_ROOT}' + r'/0/$', reface.dashboard.views.controller),
    re_path(f'{HTTP_ROOT}' + r'/reload/$', reface.dashboard.views.reload),
    re_path(f'{HTTP_ROOT}' + r'/add_box/$', reface.dashboard.views.add_box),
    re_path(f'{HTTP_ROOT}' + r'/set_name/$', reface.dashboard.views.set_name),
    re_path(f'{HTTP_ROOT}' + r'/upgrade/', reface.dashboard.views.upgrade),
    re_path(f'{HTTP_ROOT}/jsi18n/', JavaScriptCatalog.as_view(), name='javascript-catalog'),
    re_path(f'{HTTP_ROOT}/$', reface.dashboard.views.root),
]
