from .can_packet import CanSend, CanDump
from .rapida import commands as rapida_commands
from .rapida import responses as rapida_responses
from ..payloads.rapida import ServicePacket


class RapidaSend(CanSend):
    def __init__(self, module_type, module_address, end_frame, **kwargs):
        super(RapidaSend, self).__init__(module_type, module_address, end_frame, cmd=1, **kwargs)

    def check_commit(self, dump):
        pass

    def on_response(self, dump):
        if isinstance(dump, RapidaDump) and \
                (dump.command_byte == self.end_frame[0] + 1 or dump.command_byte == 0xb1 and self.end_frame[0] == 0xff):
            self.stop_answer_timer()
            return dump.payload.command

    @property
    def committed(self):
        return True

    @property
    def frame(self):
        return ((1 << 7) + self.module_type).to_bytes(1, 'big') + self.end_frame


class RapidaDump(CanDump):
    cmd = 1

    @property
    def command_byte(self):
        return self.frame[1]

    @property
    def data(self):
        return self.frame[2:]

    @property
    def payload(self):
        rs = rapida_responses.of(self.command_byte, self.data)
        if rs.__class__ == rapida_responses.Response:
            cm = rapida_commands.of(self.command_byte, self.data)
            if cm.__class__ != rapida_commands.Command and cm.__class__ != rapida_commands.Query:
                return ServicePacket(self, cm)
        return ServicePacket(self, rs)
